@@ -93,7 +93,7 @@ getGenome <-
                 dplyr::filter(
                     AssemblyFilesAllKingdoms,
                     stringr::str_detect(organism_name, organism),
-                    ((refseq_category == "representative genome") ||
+                    ((refseq_category == "representative genome") |
                          (refseq_category == "reference genome")
                     ),
                     (version_status == "latest")
