@@ -66,7 +66,7 @@ getRNA <-
             FoundOrganism <- dplyr::filter(
                 AssemblyFilesAllKingdoms,
                 stringr::str_detect(organism_name, organism),
-                ((refseq_category == "representative genome") ||
+                ((refseq_category == "representative genome") |
                      (refseq_category == "reference genome")
                 ),
                 (version_status == "latest")
